<template>
  <!-- 勤务岗位信息添加 -->
  <div>
    <el-dialog
      :before-close="handleClose"
      :title="title + '服务力量信息'"
      :visible.sync="showFormDia"
      top="8vh"
      width="76%"
    >
      <div>
        <el-form ref="formInfo" :model="params" :rules="rules" label-width="100px">
          <el-collapse v-model="activeCollapseNames" class="form-collapse">
            <el-collapse-item name="1">
              <template slot="title">
                <span class="collapse-title">
                  <i class="collapse-title-icon el-icon-info" />
                  服务力量信息
                </span>
              </template>

              <el-row>
                <el-col :span="8">
                  <el-form-item label="队伍名称" prop="name">
                    <el-input v-model="params.name" clearable placeholder="请输入队伍名称"
                              show-word-limit />
                  </el-form-item>
                </el-col>

              </el-row>
              <el-row>
                <el-col :span="24">
                  <el-form-item label="队伍描述">
                    <el-input
                      v-model="params.descripation"
                      :maxlength="500"
                      :rows="3"
                      placeholder="请输入队伍描述"
                      show-word-limit
                      style="width:100%;"
                      type="textarea"
                    />
                  </el-form-item>
                </el-col>
              </el-row>
            </el-collapse-item>
          </el-collapse>
        </el-form>
      </div>
      <span slot="footer" class="dialog-footer">
        <el-button :loading="loading" type="primary" @click="handleSave">保 存</el-button>
        <el-button @click="handleClose">取 消</el-button>
      </span>
    </el-dialog>
  </div>
</template>
<script>
import ServiceStrong from '@/views/Manage/duty/api/ServiceStrong'
import CommonApi from '@/views/Manage/CommonApi.js'
import {mapState} from 'vuex'

export default {
  name: 'CmgtDutyJobFormDialog',
  components: {},
  props: {
    equipmentList: {
      type: Array,
      default: []
    }
  },
  data() {
    return {
      title: '新增',
      CommonApi,
      showFormDia: false,
      loading: false,
      activeCollapseNames: ['1'],
      activeTabChildName: '0',

      params: {
        name: null,
        descripation: null
      },
      rules: {
        name: [
          {required: true, message: '队伍名称不能为空', trigger: 'blur'}
        ],
        descripation: [
          {required: true, message: '队伍描述不能为空', trigger: 'blur'}
        ]
      }
    }
  },
  computed: mapState({
    header: state => {
      return {
        Authorization: `Bearer ${state.login.currentUser.token}`
      }
    }
  }),
  created() {
  },
  methods: {
    add() {
      this.title = '新增'
      this.resetForm()
      this.showFormDia = true
    },
    resetForm() {
      this.params = {
        name: null,
        descripation: null
      }
    },
    handleClose() {
      this.resetForm()
      this.showFormDia = false
    },
    handleSave() {
      this.$refs.formInfo.validate(valid => {
        if (valid) {
          // this.params.areaList = this.params.areaList.map(item => {
          //   return {
          //     areaCode: item
          //   }
          // })
          let method
          if (!this.params.id) {
            // 新增
            method = ServiceStrong.addCmgtDutyJob
          } else {
            // 修改
            method = ServiceStrong.editCmgtDutyJob
          }
          this.loading = true
          method(this.params, res => {
            this.loading = false
            if (res.state) {
              this.$notify({
                type: 'success',
                message: this.title + '成功',
                duration: 2000
              })
              // this.$emit('loadData')
              this.$parent.loadData()
              this.handleClose()
            } else {
              this.$message.warning(res.message)
            }
          })
        }
      })
    },
    Update(row) {
      this.title = '修改'
      this.showFormDia = true
      ServiceStrong.getCmgtDutyJobByID(row.id, res => {
        console.log(res)
        // res.areaList = res.areaList.map(item => {
        //   return item.areaCode
        // })
        this.params = res
      })
    }
  }
}
</script>
<style lang="scss" scoped>
.step-container {
  width: 80%;
  margin: 0 auto 20px;
}

.dialog-footer {
  text-align: center;
}
</style>
